/*
  Copyright (C) 2006 Tuomas Suutari <thsuut@utu.fi>

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful, but
  WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program (see the file COPYING); if not, write to the
  Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
  MA 02110-1301 USA.
*/
#ifndef SQLIMAGEDATERANGECOLLECTION_H
#define SQLIMAGEDATERANGECOLLECTION_H
#include "DB/ImageDateCollection.h"
#include "QueryHelper.h"

namespace SQLDB
{

class SQLImageDateCollection :public DB::ImageDateCollection
{
public:
    explicit SQLImageDateCollection(QueryHelper& queryHelper);

    virtual DB::ImageCount count( const DB::ImageDate& date );
    virtual QDateTime lowerLimit() const;
    virtual QDateTime upperLimit() const;

protected:
    QueryHelper& _qh;
};

}

#endif /* SQLIMAGEDATERANGECOLLECTION_H */

